@@ -54,15 +54,14 @@ sub my_options {
 	      'of the alignment. The value is the maximum number of extra bases.',
 	      'See L<Bio::Graphics::Glyph::segments/"Displaying Alignments">.'],
 	  show_mismatch => [
-	      'string',
+	      'integer',
 	      undef,
 	      'When combined with -draw_target, highlights mismatched bases in',
-	      'the mismatch color. A value of "base level" will show the mismatch',  
-	      'when the individual bases are displayed. A value of "always" will show',
-	      'the mismatch at both the base level and the zoomed out level.',
-	      'A numeric value will show the mismatch when the track is showing',
-	      'a region less than or equal to the specified level. A value of "1"',
-	      'is identical to "base level".',
+	      'the mismatch color. A value of 0 or undef never shows mismatches.',
+	      'A value of 1 shows mismatches at the base pair alignment level, but',
+	      'not at magnifications too low to allow the DNA to be displayed.',
+	      'Any other positive integer will show mismatches when the track is showing',
+	      'a region less than or equal to the specified value.',
 	      'See L<Bio::Graphics::Glyph::segments/"Displaying Alignments">.'],
 	  mismatch_color => [
 	      'color',
@@ -114,11 +113,9 @@ sub show_mismatch {
     my $self = shift;
     my $smm = $self->option('show_mismatch');
     $smm  ||= 1 if $self->option('mismatch_only');
-    return $smm if $smm eq '1';
-    return 1 if $smm eq 'always';
-    return 1 if $smm =~ /^base/ && $self->dna_fits;
-    return 1 if $smm =~ /^\d+$/ && $smm >= $self->panel->length;
-    return;
+    return unless $smm;
+    return 1 if $smm == 1 && $self->dna_fits;
+    return 1 if $smm >= $self->panel->length;
 }
 
 sub mismatch_only { shift->option('mismatch_only') }
@@ -262,8 +259,13 @@ sub _split_on_cigar {
 	    if ($op eq 'I' || $op eq 'S' || $op eq 'H') {
 		$target_start += $count;
 	    }
-	    elsif ($op eq 'D' || $op eq 'N' || $op eq 'P') {
+	    elsif ($op eq 'D' || $op eq 'N') {
 		$source_start += $count;
+	    }
+	    elsif ($op eq 'P') {
+		# Do NOTHING for pads. Irrelevant for pairwise
+		# alignments, since we cannot show the pad in
+		# the reference sequence
 	    } else {  # everything else is assumed to be a match -- revisit
 		push @parts,[$source_start,$source_start+$count-1,
 			     $target_start,$target_start+$count-1];
@@ -279,8 +281,11 @@ sub _split_on_cigar {
 	    if ($op eq 'I' || $op eq 'S' || $op eq 'H') {
 		$target_start += $count;
 	    }
-	    elsif ($op eq 'D' || $op eq 'N' || $op eq 'P') {
+	    elsif ($op eq 'D' || $op eq 'N') {
 		$source_end -= $count;
+	    }
+	    elsif ($op eq 'P') {
+		# do nothing for pads
 	    } else {  # everything else is assumed to be a match -- revisit
 		push @parts,[$source_end-$count+1,$source_end,
 			     $target_start,$target_start+$count-1];
@@ -490,6 +495,8 @@ sub draw_multiple_alignment {
     my $cigar = $self->_get_cigar($s);
     if ($cigar || ($can_realign && $do_realign)) {
 	($ref_dna,$tgt_dna) = ($s->dna,$target->dna);
+	warn "ref/tgt" if DEBUG;
+	warn "$ref_dna\n$tgt_dna";
 	
 	my @exact_segments;
 
@@ -761,7 +768,7 @@ sub draw_multiple_alignment {
 	    my $length = $delta-1;
 	    if ($gap_distance >= $fontwidth*length($length)) {
 		my $center = $gap_left + $gap_distance/2 - ($fontwidth*length($length))/2;
-		$gd->char($font,$center,$y,$length,$color);
+		$gd->string($font,$center,$y,$length,$color);
 	    }
 	}
 	# stick in a blob
@@ -802,20 +809,22 @@ sub _gapped_alignment_to_segments {
     my $self = shift;
     my ($cigar,$sdna,$tdna) = @_;
     my ($pad_source,$pad_target,$pad_match);
+    warn "_gapped_alignment_to_segments\n$sdna\n$tdna" if DEBUG;
 
     for my $event (@$cigar) {
 	my ($op,$count) = @$event;
+	warn "op=$op, count=$count";
 	if ($op eq 'I' || $op eq 'S') {
 	    $pad_source .= '-' x $count;
 	    $pad_target .= substr($tdna,0,$count,'');
 	    $pad_match  .= ' ' x $count;
 	}
-	elsif ($op eq 'D' || $op eq 'N' || $op eq 'P') {
-	    $pad_source .= substr($tdna,0,$count,'');
+	elsif ($op eq 'D' || $op eq 'N') {
+	    $pad_source .= substr($sdna,0,$count,'');
 	    $pad_target .= '-' x $count;
 	    $pad_match  .= ' ' x $count;
 	}
-	elsif ($op eq 'H') {
+	elsif ($op eq 'H' || $op eq 'P') {
 	    # Nothing to do. This is simply an informational operation.
 	} else {  # everything else is assumed to be a match -- revisit
 	    $pad_source .= substr($sdna,0,$count,'');
@@ -824,6 +833,8 @@ sub _gapped_alignment_to_segments {
 	}
     }
 
+    warn "pads:\n$pad_source\n$pad_match\n$pad_target" if DEBUG;
+
     return $self->pads_to_segments($pad_source,$pad_match,$pad_target);
 }
 
